@@ -29,6 +29,12 @@ except NameError:
     FileNotFoundError = OSError                                 # type: ignore
 
 
+try:
+    from importlib import metadata
+except ImportError:
+    import importlib_metadata as metadata  # type: ignore
+
+
 try:
     from zipfile import Path as ZipPath  # type: ignore
 except ImportError:
